From 090b721da15619faa344860707e43ba455210060 Mon Sep 17 00:00:00 2001
From: Timothy Pearson <kb9vqf@pearsoncomputing.net>
Date: Sun, 6 Nov 2011 21:33:00 -0600
Subject: Rename additional instances of KDE to TDE

---
 cmakemodules/FindKDE4Internal.cmake | 52 ++++++++++++++++++-------------------
 cmakemodules/FindKdeLibs.cmake      | 16 ++++++------
 cmakemodules/KDE3Macros.cmake       |  6 ++---
 cmakemodules/KDE4Macros.cmake       |  6 ++---
 configdialog/CMakeLists.txt         |  6 ++---
 kbfxlib/common/CMakeLists.txt       |  6 ++---
 kbfxlib/data/CMakeLists.txt         |  6 ++---
 plugins/applications/CMakeLists.txt |  6 ++---
 plugins/plasmoids/CMakeLists.txt    |  6 ++---
 plugins/recentstuff/CMakeLists.txt  |  6 ++---
 plugins/settings/CMakeLists.txt     |  6 ++---
 plugins/strigi/CMakeLists.txt       |  6 ++---
 src/CMakeLists.txt                  |  6 ++---
 13 files changed, 67 insertions(+), 67 deletions(-)

diff --git a/cmakemodules/KDE3Macros.cmake b/cmakemodules/KDE3Macros.cmake
index b188d6c..c382972 100644
--- a/cmakemodules/KDE3Macros.cmake
+++ b/cmakemodules/KDE3Macros.cmake
@@ -12,7 +12,7 @@
 # KDE3_INSTALL_LIBTOOL_FILE
 # KDE3_CREATE_FINAL_FILE
 # KDE3_ADD_KPART
-# KDE3_ADD_KDEINIT_EXECUTABLE
+# KDE3_ADD_TDEINIT_EXECUTABLE
 # KDE3_ADD_EXECUTABLE
 
 #neundorf@kde.org
@@ -361,7 +361,7 @@ MACRO(KDE3_ADD_KPART _target_NAME _with_PREFIX)
 ENDMACRO(KDE3_ADD_KPART)
 
 
-MACRO(KDE3_ADD_KDEINIT_EXECUTABLE _target_NAME )
+MACRO(KDE3_ADD_TDEINIT_EXECUTABLE _target_NAME )
 
    IF (KDE3_ENABLE_FINAL)
       KDE3_CREATE_FINAL_FILE(${_target_NAME}_final.cpp ${ARGN})
@@ -375,7 +375,7 @@ MACRO(KDE3_ADD_KDEINIT_EXECUTABLE _target_NAME )
    ADD_EXECUTABLE( ${_target_NAME} ${CMAKE_CURRENT_BINARY_DIR}/${_target_NAME}_dummy.cpp )
    TARGET_LINK_LIBRARIES( ${_target_NAME} tdeinit_${_target_NAME} )
 
-ENDMACRO(KDE3_ADD_KDEINIT_EXECUTABLE)
+ENDMACRO(KDE3_ADD_TDEINIT_EXECUTABLE)
 
 
 MACRO(KDE3_ADD_EXECUTABLE _target_NAME )
diff --git a/cmakemodules/KDE4Macros.cmake b/cmakemodules/KDE4Macros.cmake
index ea4753d..4648ca7 100644
--- a/cmakemodules/KDE4Macros.cmake
+++ b/cmakemodules/KDE4Macros.cmake
@@ -7,7 +7,7 @@
 # KDE4_AUTOMOC
 # KDE4_INSTALL_LIBTOOL_FILE
 # KDE4_CREATE_FINAL_FILES
-# KDE4_ADD_KDEINIT_EXECUTABLE
+# KDE4_ADD_TDEINIT_EXECUTABLE
 # KDE4_ADD_EXECUTABLE
 # KDE4_ADD_WIDGET_FILES
 # KDE4_INSTALL_ICONS
@@ -636,7 +636,7 @@ macro(KDE4_CHECK_EXECUTABLE_PARAMS _output_LIST _nogui _uninst)
 endmacro(KDE4_CHECK_EXECUTABLE_PARAMS)
 
 
-macro (KDE4_ADD_KDEINIT_EXECUTABLE _target_NAME )
+macro (KDE4_ADD_TDEINIT_EXECUTABLE _target_NAME )
 
    kde4_check_executable_params(_SRCS _nogui _uninst ${ARGN})
 
@@ -667,7 +667,7 @@ macro (KDE4_ADD_KDEINIT_EXECUTABLE _target_NAME )
       target_link_libraries(${_target_NAME} ${QT_QTMAIN_LIBRARY})
    endif (WIN32)
 
-endmacro (KDE4_ADD_KDEINIT_EXECUTABLE)
+endmacro (KDE4_ADD_TDEINIT_EXECUTABLE)
 
 macro (KDE4_ADD_EXECUTABLE _target_NAME)
 
diff --git a/configdialog/CMakeLists.txt b/configdialog/CMakeLists.txt
index 33c7260..542194c 100644
--- a/configdialog/CMakeLists.txt
+++ b/configdialog/CMakeLists.txt
@@ -26,7 +26,7 @@ IF (NOT USE_KDE4)
 	TARGET_LINK_LIBRARIES(kbfxconfigapp
 	    kbfxdata
 	    kbfxcommon
-	    ${QT_AND_KDECORE_LIBS}
+	    ${QT_AND_TDECORE_LIBS}
 	    -lDCOP
 	    ${KDE3_KIO_LIBRARY}
 	    ${KDE3_UI_LIBRARY}
@@ -42,9 +42,9 @@ ELSE (NOT USE_KDE4)
 	TARGET_LINK_LIBRARIES(kbfxconfigapp
 	    kbfxdata
 	    kbfxcommon
-	    ${KDE4_KDECORE_LIBS}
+	    ${KDE4_TDECORE_LIBS}
 	    ${KDE4_KIO_LIBS}
-	    ${KDE4_KDEUI_LIBS}
+	    ${KDE4_TDEUI_LIBS}
 	    )
 ENDIF (NOT USE_KDE4)
 
diff --git a/kbfxlib/common/CMakeLists.txt b/kbfxlib/common/CMakeLists.txt
index f318f74..929c8bb 100644
--- a/kbfxlib/common/CMakeLists.txt
+++ b/kbfxlib/common/CMakeLists.txt
@@ -21,7 +21,7 @@ IF (NOT USE_KDE4)
 	#     SOVERSION ${LIB_MAJOR}
 	#     VERSION ${APPLICATION_VERSION})
 	TARGET_LINK_LIBRARIES(kbfxcommon
-	    ${QT_AND_KDECORE_LIBS}
+	    ${QT_AND_TDECORE_LIBS}
 	    ${KDE3_KIO_LIBRARY}
 	    ${KDE3_UI_LIBRARY}
 	    ${KDE3_KHTML_LIBRARY}
@@ -34,9 +34,9 @@ ELSE (NOT USE_KDE4)
 
 	KDE4_ADD_LIBRARY(kbfxcommon SHARED ${libkbfxcommonsrc})
 	TARGET_LINK_LIBRARIES(kbfxcommon
-	    ${KDE4_KDECORE_LIBS}
+	    ${KDE4_TDECORE_LIBS}
 	    ${KDE4_KIO_LIBS}
-	    ${KDE4_KDEUI_LIBS}
+	    ${KDE4_TDEUI_LIBS}
 	    ${KDE4_KHTML_LIBS}
 	    ${M_LIBRARY}
 	    )
diff --git a/kbfxlib/data/CMakeLists.txt b/kbfxlib/data/CMakeLists.txt
index 676ef78..eb99dfe 100644
--- a/kbfxlib/data/CMakeLists.txt
+++ b/kbfxlib/data/CMakeLists.txt
@@ -21,7 +21,7 @@ IF (NOT USE_KDE4)
 	#     SOVERSION ${LIB_MAJOR}
 	#     VERSION ${APPLICATION_VERSION})
 	TARGET_LINK_LIBRARIES(kbfxdata
-	    ${QT_AND_KDECORE_LIBS}
+	    ${QT_AND_TDECORE_LIBS}
 	    ${KDE3_KIO_LIBRARY}
 	    ${KDE3_UI_LIBRARY}
 	    ${KDE3_KHTML_LIBRARY}
@@ -34,9 +34,9 @@ ELSE (NOT USE_KDE4)
 
 	KDE4_ADD_LIBRARY(kbfxdata SHARED ${libkbfxdatasrc})
 	TARGET_LINK_LIBRARIES(kbfxdata
-	    ${KDE4_KDECORE_LIBS}
+	    ${KDE4_TDECORE_LIBS}
 	    ${KDE4_KIO_LIBS}
-	    ${KDE4_KDEUI_LIBS}
+	    ${KDE4_TDEUI_LIBS}
 	    ${KDE4_KHTML_LIBS}
 	    ${M_LIBRARY}
 	    )
diff --git a/plugins/applications/CMakeLists.txt b/plugins/applications/CMakeLists.txt
index 6a717fd..c4d9fc1 100644
--- a/plugins/applications/CMakeLists.txt
+++ b/plugins/applications/CMakeLists.txt
@@ -16,7 +16,7 @@ IF (NOT USE_KDE4)
 	#     VERSION ${APPLICATION_VERSION})
 	TARGET_LINK_LIBRARIES(kbfxplasmadatastub
 	    kbfxdata
-	    ${QT_AND_KDECORE_LIBS}
+	    ${QT_AND_TDECORE_LIBS}
 	    ${KDE3_KIO_LIBRARY}
 	    ${KDE3_UI_LIBRARY}
 	    ${KDE3_KHTML_LIBRARY}
@@ -30,9 +30,9 @@ ELSE (NOT USE_KDE4)
 	KDE4_ADD_LIBRARY(kbfxplasmadatastub SHARED ${libkbfxplasmadatastubsrc})
 	TARGET_LINK_LIBRARIES(kbfxplasmadatastub
 	    kbfxdata
-	    ${KDE4_KDECORE_LIBS}
+	    ${KDE4_TDECORE_LIBS}
 	    ${KDE4_KIO_LIBS}
-	    ${KDE4_KDEUI_LIBS}
+	    ${KDE4_TDEUI_LIBS}
 	    ${KDE4_KHTML_LIBS}
 	    ${M_LIBRARY}
 	    )
diff --git a/plugins/plasmoids/CMakeLists.txt b/plugins/plasmoids/CMakeLists.txt
index abb1167..49d21c8 100644
--- a/plugins/plasmoids/CMakeLists.txt
+++ b/plugins/plasmoids/CMakeLists.txt
@@ -16,7 +16,7 @@ IF (NOT USE_KDE4)
 	#     VERSION ${APPLICATION_VERSION})
 	TARGET_LINK_LIBRARIES(kbfxplasmadataplasmoid
 	    kbfxdata
-	    ${QT_AND_KDECORE_LIBS}
+	    ${QT_AND_TDECORE_LIBS}
 	    ${KDE3_KIO_LIBRARY}
 	    ${KDE3_UI_LIBRARY}
 	    ${KDE3_KHTML_LIBRARY}
@@ -30,9 +30,9 @@ ELSE (NOT USE_KDE4)
 	KDE4_ADD_LIBRARY(kbfxplasmadataplasmoid SHARED ${libkbfxplasmadataplasmoidsrc} )
 	TARGET_LINK_LIBRARIES(kbfxplasmadataplasmoid
 	    kbfxdata
-	    ${KDE4_KDECORE_LIBS}
+	    ${KDE4_TDECORE_LIBS}
 	    ${KDE4_KIO_LIBS}
-	    ${KDE4_KDEUI_LIBS}
+	    ${KDE4_TDEUI_LIBS}
 	    ${KDE4_KHTML_LIBS}
 	    ${M_LIBRARY}
 	    )
diff --git a/plugins/recentstuff/CMakeLists.txt b/plugins/recentstuff/CMakeLists.txt
index 787fbd8..f5f3f83 100644
--- a/plugins/recentstuff/CMakeLists.txt
+++ b/plugins/recentstuff/CMakeLists.txt
@@ -16,7 +16,7 @@ IF (NOT USE_KDE4)
 	#     VERSION ${APPLICATION_VERSION})
 	TARGET_LINK_LIBRARIES(kbfxplasmarecentstuff
 	    kbfxdata
-	    ${QT_AND_KDECORE_LIBS}
+	    ${QT_AND_TDECORE_LIBS}
 	    ${KDE3_KIO_LIBRARY}
 	    ${KDE3_UI_LIBRARY}
 	    ${KDE3_KHTML_LIBRARY}
@@ -30,9 +30,9 @@ ELSE (NOT USE_KDE4)
 	KDE4_ADD_LIBRARY(kbfxplasmarecentstuff SHARED ${libkbfxplasmarecentstuffsrc} )
 	TARGET_LINK_LIBRARIES(kbfxplasmarecentstuff
 	    kbfxdata
-	    ${KDE4_KDECORE_LIBS}
+	    ${KDE4_TDECORE_LIBS}
 	    ${KDE4_KIO_LIBS}
-	    ${KDE4_KDEUI_LIBS}
+	    ${KDE4_TDEUI_LIBS}
 	    ${KDE4_KHTML_LIBS}
 	    ${M_LIBRARY}
 	    )
diff --git a/plugins/settings/CMakeLists.txt b/plugins/settings/CMakeLists.txt
index 2ef6f02..99bbaba 100644
--- a/plugins/settings/CMakeLists.txt
+++ b/plugins/settings/CMakeLists.txt
@@ -16,7 +16,7 @@ IF (NOT USE_KDE4)
 	#     VERSION ${APPLICATION_VERSION})
 	TARGET_LINK_LIBRARIES(kbfxplasmadatasettings
 	    kbfxdata
-	    ${QT_AND_KDECORE_LIBS}
+	    ${QT_AND_TDECORE_LIBS}
 	    ${KDE3_KIO_LIBRARY}
 	    ${KDE3_UI_LIBRARY}
 	    ${KDE3_KHTML_LIBRARY}
@@ -30,9 +30,9 @@ ELSE (NOT USE_KDE4)
 	KDE4_ADD_LIBRARY(kbfxplasmadatasettings SHARED ${libkbfxplasmadatasettingssrc})
 	TARGET_LINK_LIBRARIES(kbfxplasmadatasettings
 	    kbfxdata
-	    ${KDE4_KDECORE_LIBS}
+	    ${KDE4_TDECORE_LIBS}
 	    ${KDE4_KIO_LIBS}
-	    ${KDE4_KDEUI_LIBS}
+	    ${KDE4_TDEUI_LIBS}
 	    ${KDE4_KHTML_LIBS}
 	    ${M_LIBRARY}
 	    )
diff --git a/plugins/strigi/CMakeLists.txt b/plugins/strigi/CMakeLists.txt
index 29289b0..061b425 100644
--- a/plugins/strigi/CMakeLists.txt
+++ b/plugins/strigi/CMakeLists.txt
@@ -16,7 +16,7 @@ IF (NOT USE_KDE4)
 	#     VERSION ${APPLICATION_VERSION})
 	TARGET_LINK_LIBRARIES(kbfxstrigiclient
 	    kbfxdata
-	    ${QT_AND_KDECORE_LIBS}
+	    ${QT_AND_TDECORE_LIBS}
 	    ${KDE3_KIO_LIBRARY}
 	    ${KDE3_UI_LIBRARY}
 	    ${KDE3_KHTML_LIBRARY}
@@ -31,9 +31,9 @@ ELSE (NOT USE_KDE4)
 	KDE4_ADD_LIBRARY(kbfxstrigiclient SHARED ${libkbfxstrigiclientsrc})
 	TARGET_LINK_LIBRARIES(kbfxstrigiclient
 	    kbfxdata
-	    ${KDE4_KDECORE_LIBS}
+	    ${KDE4_TDECORE_LIBS}
 	    ${KDE4_KIO_LIBS}
-	    ${KDE4_KDEUI_LIBS}
+	    ${KDE4_TDEUI_LIBS}
 	    ${KDE4_KHTML_LIBS}
 	    ${M_LIBRARY}
 	    ${STRIGICLIENT_LIBRARY}
diff --git a/src/CMakeLists.txt b/src/CMakeLists.txt
index 3e76368..c81c616 100644
--- a/src/CMakeLists.txt
+++ b/src/CMakeLists.txt
@@ -35,7 +35,7 @@ IF (NOT USE_KDE4)
 	TARGET_LINK_LIBRARIES(kbfxspinx
 	    kbfxdata
 	    kbfxcommon
-	    ${QT_AND_KDECORE_LIBS}
+	    ${QT_AND_TDECORE_LIBS}
 	    ${KDE3_UI_LIBRARY}
 	    )
 
@@ -51,8 +51,8 @@ ELSE (NOT USE_KDE4)
 	TARGET_LINK_LIBRARIES(kbfxspinx
 	    kbfxdata
 	    kbfxcommon
-	    ${KDE4_KDECORE_LIBS}
-	    ${KDE4_KDEUI_LIBS}
+	    ${KDE4_TDECORE_LIBS}
+	    ${KDE4_TDEUI_LIBS}
 	    )
 
 	KDE4_INSTALL_LIBTOOL_FILE(kbfxspinx ${PLUGIN_INSTALL_DIR})
diff --git a/cmakemodules/FindKDE4Internal.cmake b/cmakemodules/FindKDE4Internal.cmake
index 7238a35..d96433f 100644
--- a/cmakemodules/FindKDE4Internal.cmake
+++ b/cmakemodules/FindKDE4Internal.cmake
@@ -22,8 +22,8 @@
 # The following variables point to the location of the KDE libraries,
 # but shouldn't be used directly:
 #
 # KDE4_KDECORE_LIBRARY     - the tdecore library
 # KDE4_KDEUI_LIBRARY       - the tdeui library
 # KDE4_KIO_LIBRARY         - the kio library
 # KDE4_KPARTS_LIBRARY      - the kparts library
 # KDE4_KUTILS_LIBRARY      - the kutils library
@@ -32,13 +32,13 @@
 # KDE4_KHTML_LIBRARY       - the khtml library
 # KDE4_KJS_LIBRARY         - the kjs library
 # KDE4_KNEWSTUFF_LIBRARY   - the knewstuff library
 # KDE4_KDEPRINT_LIBRARY    - the tdeprint library
 # KDE4_KSPELL2_LIBRARY     - the kspell2 library
 # KDE4_KDNSSD_LIBRARY      - the kdnssd library
 # KDE4_PHONONCORE_LIBRARY  - the phononcore library
 # KDE4_PHONONUI_LIBRARY    - the phononui library
 # KDE4_KAUDIODEVICELIST_LIBRARY - the kaudiodevicelist library
 # KDE4_KDEFX_LIBRARY       - the tdefx library
 # KDE4_THREADWEAVER_LIBRARY- the threadweaver library
 # KDE4_SOLID_LIBRARY       - the solid library
 # KDE4_SOLIDIFACES_LIBRARY - the solidiface library
@@ -51,8 +51,8 @@
 # also contain all of the depending libraries, so the variables below
 # should be used instead of the ones above:
 #
 # KDE4_KDECORE_LIBS          - the tdecore library and all depending libraries
 # KDE4_KDEUI_LIBS            - the tdeui library and all depending libraries
 # KDE4_KIO_LIBS              - the kio library and all depending libraries
 # KDE4_KPARTS_LIBS           - the kparts library and all depending libraries
 # KDE4_KUTILS_LIBS           - the kutils library and all depending libraries
@@ -61,13 +61,13 @@
 # KDE4_KHTML_LIBS            - the khtml library and all depending libraries
 # KDE4_KJS_LIBS              - the kjs library and all depending libraries
 # KDE4_KNEWSTUFF_LIBS        - the knewstuff library and all depending libraries
 # KDE4_KDEPRINT_LIBS         - the tdeprint library and all depending libraries
 # KDE4_KSPELL2_LIBS          - the kspell2 library and all depending libraries
 # KDE4_KDNSSD_LIBS           - the kdnssd library and all depending libraries
 # KDE4_KDESU_LIBS            - the tdesu library and all depending libraries
 # KDE4_PHONONCORE_LIBS       - the phononcore library and all depending librairies
 # KDE4_PHONONUI_LIBRARIES    - the phononui library and all depending librairies
 # KDE4_KDEFX_LIBS            - the tdefx library and all depending librairies
 # KDE4_THREADWEAVER_LIBRARIES- the threadweaver library and all depending libraries
 # KDE4_SOLID_LIBS            - the solid library and all depending libraries
 # KDE4_SOLIDIFACES_LIBS      - the solid iface library and all depending libraries
@@ -155,7 +155,7 @@
 #    If WITH_PREFIX is given, the resulting plugin will have the prefix "lib", otherwise it won't.
 #    It creates and installs an appropriate libtool la-file.
 #
-# KDE4_ADD_KDEINIT_EXECUTABLE (name [NOGUI] [RUN_UNINSTALLED] file1 ... fileN)
+# KDE4_ADD_TDEINIT_EXECUTABLE (name [NOGUI] [RUN_UNINSTALLED] file1 ... fileN)
 #    Create a KDE application in the form of a module loadable via tdeinit.
 #    A library named tdeinit_<name> will be created and a small executable which links to it.
 #    It supports KDE4_ENABLE_FINAL
@@ -328,12 +328,12 @@ if(EXISTS ${CMAKE_SOURCE_DIR}/tdecore/kernel/kglobal.h)
    message(STATUS "Building kdelibs...")
 
    set(KDE4_INCLUDE_DIR ${CMAKE_SOURCE_DIR})
-   set(KDE4_KDECORE_LIBS ${QT_QTCORE_LIBRARY} tdecore)
-   set(KDE4_KDEUI_LIBS ${KDE4_KDECORE_LIBS} tdeui)
-   set(KDE4_KIO_LIBS ${KDE4_KDEUI_LIBS} kio)
+   set(KDE4_TDECORE_LIBS ${QT_QTCORE_LIBRARY} tdecore)
+   set(KDE4_TDEUI_LIBS ${KDE4_TDECORE_LIBS} tdeui)
+   set(KDE4_KIO_LIBS ${KDE4_TDEUI_LIBS} kio)
    set(KDE4_KPARTS_LIBS ${KDE4_KIO_LIBS} kparts)
    set(KDE4_KUTILS_LIBS ${KDE4_KIO_LIBS} kutils)
-   set(KDE4_KDEFX_LIBS ${KDE4_KDEFX_LIBS} tdefx)
+   set(KDE4_TDEFX_LIBS ${KDE4_TDEFX_LIBS} tdefx)
 
 
    set(EXECUTABLE_OUTPUT_PATH ${CMAKE_BINARY_DIR}/bin )
@@ -394,14 +394,14 @@ else(EXISTS ${CMAKE_SOURCE_DIR}/tdecore/kernel/kglobal.h)
    # this file contains all dependencies of all libraries of kdelibs, Alex
    include(${kde_cmake_module_dir}/KDELibsDependencies.cmake)
 
-   find_library(KDE4_KDECORE_LIBRARY NAMES tdecore PATHS ${KDE4_LIB_INSTALL_DIR} NO_DEFAULT_PATH )
-   set(KDE4_KDECORE_LIBS ${tdecore_LIB_DEPENDS} ${KDE4_KDECORE_LIBRARY} )
+   find_library(KDE4_TDECORE_LIBRARY NAMES tdecore PATHS ${KDE4_LIB_INSTALL_DIR} NO_DEFAULT_PATH )
+   set(KDE4_TDECORE_LIBS ${tdecore_LIB_DEPENDS} ${KDE4_TDECORE_LIBRARY} )
 
-   find_library(KDE4_KDEFX_LIBRARY NAMES tdefx PATHS ${KDE4_LIB_INSTALL_DIR} NO_DEFAULT_PATH )
-   set(KDE4_KDEFX_LIBS ${tdefx_LIB_DEPENDS} ${KDE4_KDEFX_LIBRARY} )
+   find_library(KDE4_TDEFX_LIBRARY NAMES tdefx PATHS ${KDE4_LIB_INSTALL_DIR} NO_DEFAULT_PATH )
+   set(KDE4_TDEFX_LIBS ${tdefx_LIB_DEPENDS} ${KDE4_TDEFX_LIBRARY} )
 
-   find_library(KDE4_KDEUI_LIBRARY NAMES tdeui PATHS ${KDE4_LIB_INSTALL_DIR} NO_DEFAULT_PATH )
-   set(KDE4_KDEUI_LIBS ${tdeui_LIB_DEPENDS} ${KDE4_KDEUI_LIBRARY} )
+   find_library(KDE4_TDEUI_LIBRARY NAMES tdeui PATHS ${KDE4_LIB_INSTALL_DIR} NO_DEFAULT_PATH )
+   set(KDE4_TDEUI_LIBS ${tdeui_LIB_DEPENDS} ${KDE4_TDEUI_LIBRARY} )
 
    find_library(KDE4_KIO_LIBRARY NAMES kio PATHS ${KDE4_LIB_INSTALL_DIR} NO_DEFAULT_PATH )
    set(KDE4_KIO_LIBS ${kio_LIB_DEPENDS} ${KDE4_KIO_LIBRARY} )
@@ -424,15 +424,15 @@ else(EXISTS ${CMAKE_SOURCE_DIR}/tdecore/kernel/kglobal.h)
    find_library(KDE4_KNEWSTUFF_LIBRARY NAMES knewstuff PATHS ${KDE4_LIB_INSTALL_DIR} NO_DEFAULT_PATH )
    set(KDE4_KNEWSTUFF_LIBS ${knewstuff_LIB_DEPENDS} ${KDE4_KNEWSTUFF_LIBRARY} )
 
-   find_library(KDE4_KDEPRINT_LIBRARY NAMES tdeprint PATHS ${KDE4_LIB_INSTALL_DIR} NO_DEFAULT_PATH )
-   set(KDE4_KDEPRINT_LIBS ${tdeprint_LIB_DEPENDS} ${KDE4_KDEPRINT_LIBRARY} )
+   find_library(KDE4_TDEPRINT_LIBRARY NAMES tdeprint PATHS ${KDE4_LIB_INSTALL_DIR} NO_DEFAULT_PATH )
+   set(KDE4_TDEPRINT_LIBS ${tdeprint_LIB_DEPENDS} ${KDE4_TDEPRINT_LIBRARY} )
 
    find_library(KDE4_KSPELL2_LIBRARY NAMES kspell2 PATHS ${KDE4_LIB_INSTALL_DIR} NO_DEFAULT_PATH )
    set(KDE4_KSPELL2_LIBS ${kspell2_LIB_DEPENDS} ${KDE4_KSPELL2_LIBRARY} )
 
    if (UNIX)
-      find_library(KDE4_KDESU_LIBRARY NAMES tdesu PATHS ${KDE4_LIB_INSTALL_DIR} NO_DEFAULT_PATH )
-      set(KDE4_KDESU_LIBS ${tdesu_LIB_DEPENDS} ${KDE4_KDESU_LIBRARY} )
+      find_library(KDE4_TDESU_LIBRARY NAMES tdesu PATHS ${KDE4_LIB_INSTALL_DIR} NO_DEFAULT_PATH )
+      set(KDE4_TDESU_LIBS ${tdesu_LIB_DEPENDS} ${KDE4_TDESU_LIBRARY} )
    endif (UNIX)
 
    find_library(KDE4_KDNSSD_LIBRARY NAMES kdnssd PATHS ${KDE4_LIB_INSTALL_DIR} NO_DEFAULT_PATH )
@@ -472,7 +472,7 @@ else(EXISTS ${CMAKE_SOURCE_DIR}/tdecore/kernel/kglobal.h)
    find_library(KDE4_KWALLETCLIENT_LIBRARY NAMES kwalletclient PATHS ${KDE4_LIB_INSTALL_DIR} )
    set(KDE4_KWALLETCLIENT_LIBS ${kwalletclient_LIB_DEPENDS} ${KDE4_KWALLETCLIENT_LIBRARY} )
    
-   get_filename_component(KDE4_LIB_DIR ${KDE4_KDECORE_LIBRARY} PATH )
+   get_filename_component(KDE4_LIB_DIR ${KDE4_TDECORE_LIBRARY} PATH )
 
 
    # at first the KDE include direcory
@@ -544,7 +544,7 @@ if (WIN32)
    # if we are compiling kdelibs, add KDEWIN32_LIBRARIES explicitely,
    # otherwise they come from KDELibsDependencies.cmake, Alex
    if(EXISTS ${CMAKE_SOURCE_DIR}/tdecore/kernel/kglobal.h)
-      set( KDE4_KDECORE_LIBS ${KDE4_KDECORE_LIBS} ${KDEWIN32_LIBRARIES} )
+      set( KDE4_TDECORE_LIBS ${KDE4_TDECORE_LIBS} ${KDEWIN32_LIBRARIES} )
    endif(EXISTS ${CMAKE_SOURCE_DIR}/tdecore/kernel/kglobal.h)
 
    # windows, mingw
@@ -22,8 +22,8 @@
 # but shouldn't be used directly:
 #
-# KDE4_KDECORE_LIBRARY     - the tdecore library
-# KDE4_KDEUI_LIBRARY       - the tdeui library
+# KDE4_TDECORE_LIBRARY     - the tdecore library
+# KDE4_TDEUI_LIBRARY       - the tdeui library
 # KDE4_KIO_LIBRARY         - the kio library
 # KDE4_KPARTS_LIBRARY      - the kparts library
@@ -32,13 +32,13 @@
 # KDE4_KJS_LIBRARY         - the kjs library
 # KDE4_KNEWSTUFF_LIBRARY   - the knewstuff library
-# KDE4_KDEPRINT_LIBRARY    - the tdeprint library
+# KDE4_TDEPRINT_LIBRARY    - the tdeprint library
 # KDE4_KSPELL2_LIBRARY     - the kspell2 library
 # KDE4_KDNSSD_LIBRARY      - the kdnssd library
@@ -32,13 +32,13 @@
 # KDE4_PHONONUI_LIBRARY    - the phononui library
 # KDE4_KAUDIODEVICELIST_LIBRARY - the kaudiodevicelist library
-# KDE4_KDEFX_LIBRARY       - the tdefx library
+# KDE4_TDEFX_LIBRARY       - the tdefx library
 # KDE4_THREADWEAVER_LIBRARY- the threadweaver library
 # KDE4_SOLID_LIBRARY       - the solid library
@@ -51,8 +51,8 @@
 # should be used instead of the ones above:
 #
-# KDE4_KDECORE_LIBS          - the tdecore library and all depending libraries
-# KDE4_KDEUI_LIBS            - the tdeui library and all depending libraries
+# KDE4_TDECORE_LIBS          - the tdecore library and all depending libraries
+# KDE4_TDEUI_LIBS            - the tdeui library and all depending libraries
 # KDE4_KIO_LIBS              - the kio library and all depending libraries
 # KDE4_KPARTS_LIBS           - the kparts library and all depending libraries
@@ -61,13 +61,13 @@
 # KDE4_KJS_LIBS              - the kjs library and all depending libraries
 # KDE4_KNEWSTUFF_LIBS        - the knewstuff library and all depending libraries
-# KDE4_KDEPRINT_LIBS         - the tdeprint library and all depending libraries
+# KDE4_TDEPRINT_LIBS         - the tdeprint library and all depending libraries
 # KDE4_KSPELL2_LIBS          - the kspell2 library and all depending libraries
 # KDE4_KDNSSD_LIBS           - the kdnssd library and all depending libraries
@@ -61,13 +61,13 @@
 # KDE4_KSPELL2_LIBS          - the kspell2 library and all depending libraries
 # KDE4_KDNSSD_LIBS           - the kdnssd library and all depending libraries
-# KDE4_KDESU_LIBS            - the tdesu library and all depending libraries
+# KDE4_TDESU_LIBS            - the tdesu library and all depending libraries
 # KDE4_PHONONCORE_LIBS       - the phononcore library and all depending librairies
 # KDE4_PHONONUI_LIBRARIES    - the phononui library and all depending librairies
@@ -61,13 +61,13 @@
 # KDE4_PHONONCORE_LIBS       - the phononcore library and all depending librairies
 # KDE4_PHONONUI_LIBRARIES    - the phononui library and all depending librairies
-# KDE4_KDEFX_LIBS            - the tdefx library and all depending librairies
+# KDE4_TDEFX_LIBS            - the tdefx library and all depending librairies
 # KDE4_THREADWEAVER_LIBRARIES- the threadweaver library and all depending libraries
 # KDE4_SOLID_LIBS            - the solid library and all depending libraries
diff --git a/cmakemodules/FindKdeLibs.cmake b/cmakemodules/FindKdeLibs.cmake
index 85d6c2a..356c0e4 100644
--- a/cmakemodules/FindKdeLibs.cmake
+++ b/cmakemodules/FindKdeLibs.cmake
@@ -7,7 +7,7 @@ include(FindQt3)
 #  KDE3_INCLUDE_DIR         - the KDE include directory
 #  KDE3_INCLUDE_DIRS        - the KDE and the Qt include directory, for use with INCLUDE_DIRECTORIES()
 #  KDE3_LIB_DIR             - the directory where the KDE libraries are installed, for use with LINK_DIRECTORIES()
 #  QT_AND_KDECORE_LIBS      - this contains both the Qt and the tdecore library
 #  KDE3_DCOPIDL_EXECUTABLE  - the dcopidl executable
 #  KDE3_DCOPIDL2CPP_EXECUTABLE - the dcopidl2cpp executable
 #  KDE3_KCFGC_EXECUTABLE    - the kconfig_compiler executable
@@ -55,7 +55,7 @@ include(FindQt3)
 #    If WITH_PREFIX is given, the resulting plugin will have the prefix "lib", otherwise it won't.
 #    It creates and installs an appropriate libtool la-file.
 #
-# KDE3_ADD_KDEINIT_EXECUTABLE(name file1 ... fileN )
+# KDE3_ADD_TDEINIT_EXECUTABLE(name file1 ... fileN )
 #    Create a KDE application in the form of a module loadable via tdeinit.
 #    A library named tdeinit_<name> will be created and a small executable which links to it.
 #
@@ -139,7 +139,7 @@ FIND_PATH(KDE3_INCLUDE_DIR kpassdlg.h
 # SET(KDE3_INCLUDE_DIR "/usr/include/kde")
 
 #now the KDE library directory
-FIND_LIBRARY(KDE3_KDECORE_LIBRARY NAMES tdecore
+FIND_LIBRARY(KDE3_TDECORE_LIBRARY NAMES tdecore
   HINTS
   $ENV{KDEDIR}/lib
   ${KDE3PREFIX}/lib
@@ -150,16 +150,16 @@ FIND_LIBRARY(KDE3_KDECORE_LIBRARY NAMES tdecore
   /usr/trinity/lib
 )
 
-SET(QT_AND_KDECORE_LIBS ${QT_LIBRARIES} ${KDE3_KDECORE_LIBRARY})
+SET(QT_AND_TDECORE_LIBS ${QT_LIBRARIES} ${KDE3_TDECORE_LIBRARY})
 
-GET_FILENAME_COMPONENT(KDE3_LIB_DIR ${KDE3_KDECORE_LIBRARY} PATH )
+GET_FILENAME_COMPONENT(KDE3_LIB_DIR ${KDE3_TDECORE_LIBRARY} PATH )
 
 IF(NOT KDE3_LIBTOOL_DIR)
-   IF(KDE3_KDECORE_LIBRARY MATCHES lib64)
+   IF(KDE3_TDECORE_LIBRARY MATCHES lib64)
      SET(KDE3_LIBTOOL_DIR /lib64/trinity)
-   ELSE(KDE3_KDECORE_LIBRARY MATCHES lib64)
+   ELSE(KDE3_TDECORE_LIBRARY MATCHES lib64)
      SET(KDE3_LIBTOOL_DIR /lib/trinity)
-   ENDIF(KDE3_KDECORE_LIBRARY MATCHES lib64)
+   ENDIF(KDE3_TDECORE_LIBRARY MATCHES lib64)
 ENDIF(NOT KDE3_LIBTOOL_DIR)
 
 #now search for the dcop utilities
@@ -7,7 +7,7 @@ include(FindQt3)
 #  KDE3_INCLUDE_DIRS        - the KDE and the Qt include directory, for use with INCLUDE_DIRECTORIES()
 #  KDE3_LIB_DIR             - the directory where the KDE libraries are installed, for use with LINK_DIRECTORIES()
-#  QT_AND_KDECORE_LIBS      - this contains both the Qt and the tdecore library
+#  QT_AND_TDECORE_LIBS      - this contains both the Qt and the tdecore library
 #  KDE3_DCOPIDL_EXECUTABLE  - the dcopidl executable
 #  KDE3_DCOPIDL2CPP_EXECUTABLE - the dcopidl2cpp executable
-- 
cgit v1.2.3

